spendtime
=========

A simple timetracking tool for the terminal.

Installation
------------

``$ pip3 install spendtime``

Usage
-----

*spendtime* saves its data in a database in the working directory.
Simply type the command ``spendtime`` in your terminal (or command
prompt on windows) and it will start tracking time in its default
timetable. If you want to track time on different things, several tables
can be created and used. Check ``spendtime --help`` for more info.
